/**
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestNGObjectFactory.java 6135 2012-01-24 17:02:48Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.testng4osgi.factory;

import org.osgi.framework.BundleContext;
import org.ow2.util.testng4osgi.inject.TestNGInject;
import org.testng.IObjectFactory2;

/**
 * Factory used to add dependency injection. 
 * @author Florent Benoit
 */
public class TestNGObjectFactory implements IObjectFactory2 {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1704618482226341327L;

    /**
     * Inject helper.
     */
    private TestNGInject testNGInject = null;
    
    /**
     * Default constructor.
     * @param bundleContext the given bundle context
     */
    public TestNGObjectFactory(BundleContext bundleContext) {
        this.testNGInject = new TestNGInject(bundleContext);
    }
    
    /**
     * Callback used to instantiate a new instance of the given class
     * @param clazz the given class
     */
    public Object newInstance(Class<?> clazz) {
        Object instance = null;
        try {
            instance = clazz.newInstance();
        } catch (Exception e) {
            throw new IllegalStateException("Error while making instance", e);
        }
        testNGInject.inject(instance);
        return instance;
        
    }
}
