/**
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EnhancedTestNG.java 6135 2012-01-24 17:02:48Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.testng4osgi.launcher;

import java.util.Arrays;
import java.util.List;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.testng.TestNG;
import org.testng.internal.Utils;
import org.testng.xml.XmlClass;
import org.testng.xml.XmlSuite;
import org.testng.xml.XmlTest;

/**
 * Allows to enhance TestNG
 * @author Florent Benoit
 */
public class EnhancedTestNG extends TestNG {

    /**
     * Logger.
     */
    private static final Log LOGGER = LogFactory.getLog(EnhancedTestNG.class);

    /**
     * Bundle context.
     */
    private BundleContext bundleContext = null;
    
    /**
     * Default constructor.
     * @param bundleContext the given bundle context
     */
    public EnhancedTestNG(BundleContext bundleContext) {
        this.bundleContext = bundleContext;
    }
    
    public void setOSGiClasses(List<Class<?>> classes) {

        // Create a new XML suite
        XmlClass[] xmlClassesArray = Utils.classesToXmlClasses(classes.toArray(new Class[classes.size()]));
        Bundle bundle = bundleContext.getBundle();
        String suiteName = "Bundle_".concat(bundle.getSymbolicName()).concat("_").concat(Long.toString(bundle.getBundleId()));
        XmlSuite xmlSuite = new XmlSuite();
        xmlSuite.setName(suiteName);
        XmlTest xmlTest = null;
        xmlTest = new XmlTest(xmlSuite);
        xmlTest.setName("Test");
        xmlTest.setXmlClasses(Arrays.asList(xmlClassesArray));
        
        setCommandLineSuite(xmlSuite);
        
    }
    
    
    @Override
    public void run() {
        try {
            super.run();
        } catch (RuntimeException e) {
            LOGGER.error("Error while running TestNG", e);
            setHasFailure(true);
        } catch (Exception e) {
            LOGGER.error("Error while running TestNG", e);
            setHasFailure(true);
        }
    }
    
    
}
